/* **********************************************************
 * Copyright 2011-2016 VMware, Inc.  All rights reserved.
 * **********************************************************/

/*
 * The sample program enables Application Monitoring and sends heartbeats
 * every 15 seconds. Once the program is running issuing Ctrl-c will bring
 * three choice:
 * stop(s)     - stop heartbeating and exit program. This should cause a
 * reset of the VM
 * disable(d)  - disable application monitoring and exit program. This will
 * not cause a reset.
 * continue(c) - keep sending heartbeats.
 *
 * Please make sure you are running ESX[i] 4.1 or later. Please,
 * also, make sure you enabled application monitoring while configuring HA.
 */

#include "vmGuestAppMonitorLib.h"

#include <stdio.h>
#include <unistd.h>
#include <signal.h>
#include <stdlib.h>

static void
CtrlHandler(int sig)
{
   char c, c1;
   int error;

   signal(sig, SIG_IGN);

   printf( "Please chose heartbeat action: stop(s), disable(d), continue(c) \n\n" );

   c1 = getchar();
   while (c1 != '\n' && c1 != EOF) {
      c = c1;
      c1 = getchar();
   }

   switch(c) {
   case 'c':
      printf("Continuing heartbeating\n");
      break;
   case 'd':
      printf("Disabling app monitoring\n");
      error = VMGuestAppMonitor_Disable();
      if (error != VMGUESTAPPMONITORLIB_ERROR_SUCCESS) {
         printf("Error %d disabling app monitoring\n", error);
         exit(1);
      }
      exit(0);
   case 's':
      printf("Stopping heartbeating\n");
      exit(0);
   default:
      printf("Invalid action %c\n", c);
   }

   signal(SIGINT, CtrlHandler);
   return;
}

int
main(int argc,
     char ** argv)
{
   int error;

   signal(SIGINT, CtrlHandler);

   printf("Enabling app monitoring\n");
   error = VMGuestAppMonitor_Enable();

   if (error != VMGUESTAPPMONITORLIB_ERROR_SUCCESS) {
      printf("Error %d enabling app monitoring\n", error);
      return error;
   }

   while(1) {
      error = VMGuestAppMonitor_MarkActive();
      if (error != VMGUESTAPPMONITORLIB_ERROR_SUCCESS) {
         printf("Error %d heartbeating\n", error);
         return error;
      }

      sleep(15);
   }

   return 0;
}
